# ROCKART

[Rockart](https://github.com/van-kalsing/rockart) is a tool for drawing in terminal using
[Braille](https://en.wikipedia.org/wiki/Braille) characters. Inspired by
[Drawille](https://github.com/asciimoo/drawille).
